@@ -1,10 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2019, Andrew Klychkov (@Andersson007) <aaklychkov@mail.ru>
+# Copyright: (c) 2019, Andrew Klychkov (@Andersson007) <andrew.a.klychkov@gmail.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -27,12 +28,12 @@ options:
       the excluding values will be ignored.
     type: list
     elements: str
-  db:
+  login_db:
     description:
     - Name of database to connect.
     type: str
     aliases:
-    - login_db
+    - db
   session_role:
     description:
     - Switch to session_role after connecting. The specified session_role must
@@ -93,7 +94,7 @@ EXAMPLES = r'''
   become: true
   become_user: pgsql
   community.postgresql.postgresql_info:
-    db: postgres
+    login_db: postgres
     filter:
     - tablesp*
     - repl_sl*
@@ -108,39 +109,9 @@ EXAMPLES = r'''
 
 RETURN = r'''
 version:
-  description: Database server version U(https://www.postgresql.org/support/versioning/).
+  description: Database server version.
   returned: success
   type: dict
-  sample: { "version": { "major": 10, "minor": 6 } }
-  contains:
-    major:
-      description: Major server version.
-      returned: success
-      type: int
-      sample: 11
-    minor:
-      description: Minor server version.
-      returned: success
-      type: int
-      sample: 1
-    patch:
-      description: Patch server version.
-      returned: if supported
-      type: int
-      sample: 5
-      version_added: '1.2.0'
-    full:
-      description: Full server version.
-      returned: success
-      type: str
-      sample: '13.2'
-      version_added: '1.2.0'
-    raw:
-      description: Full output returned by ``SELECT version()``.
-      returned: success
-      type: str
-      sample: 'PostgreSQL 13.2 on x86_64-pc-linux-gnu, compiled by gcc (GCC) 10.2.1 20201125 (Red Hat 10.2.1-9), 64-bit'
-      version_added: '1.2.0'
 in_recovery:
   description: Indicates if the service is in recovery mode or not.
   returned: success
@@ -150,377 +121,46 @@ databases:
   description: Information about databases.
   returned: success
   type: dict
-  sample:
-  - { "postgres": { "access_priv": "", "collate": "en_US.UTF-8",
-  "ctype": "en_US.UTF-8", "encoding": "UTF8", "owner": "postgres", "size": "7997 kB" } }
-  contains:
-    database_name:
-      description: Database name.
-      returned: success
-      type: dict
-      sample: template1
-      contains:
-        access_priv:
-          description: Database access privileges.
-          returned: success
-          type: str
-          sample: "=c/postgres_npostgres=CTc/postgres"
-        collate:
-          description:
-          - Database collation U(https://www.postgresql.org/docs/current/collation.html).
-          returned: success
-          type: str
-          sample: en_US.UTF-8
-        ctype:
-          description:
-          - Database LC_CTYPE U(https://www.postgresql.org/docs/current/multibyte.html).
-          returned: success
-          type: str
-          sample: en_US.UTF-8
-        encoding:
-          description:
-          - Database encoding U(https://www.postgresql.org/docs/current/multibyte.html).
-          returned: success
-          type: str
-          sample: UTF8
-        owner:
-          description:
-          - Database owner U(https://www.postgresql.org/docs/current/sql-createdatabase.html).
-          returned: success
-          type: str
-          sample: postgres
-        size:
-          description: Database size in bytes.
-          returned: success
-          type: str
-          sample: 8189415
-        extensions:
-          description:
-          - Extensions U(https://www.postgresql.org/docs/current/sql-createextension.html).
-          returned: success
-          type: dict
-          sample:
-          - { "plpgsql": { "description": "PL/pgSQL procedural language",
-            "extversion": { "major": 1, "minor": 0, "raw": '1.0' } } }
-          contains:
-            extdescription:
-              description: Extension description.
-              returned: if existent
-              type: str
-              sample: PL/pgSQL procedural language
-            extversion:
-              description: Extension description.
-              returned: success
-              type: dict
-              contains:
-                major:
-                  description: Extension major version.
-                  returned: success
-                  type: int
-                  sample: 1
-                minor:
-                  description: Extension minor version.
-                  returned: success
-                  type: int
-                  sample: 0
-                raw:
-                  description: Extension full version.
-                  returned: success
-                  type: str
-                  sample: '1.0'
-            nspname:
-              description: Namespace where the extension is.
-              returned: success
-              type: str
-              sample: pg_catalog
-        languages:
-          description: Procedural languages U(https://www.postgresql.org/docs/current/xplang.html).
-          returned: success
-          type: dict
-          sample: { "sql": { "lanacl": "", "lanowner": "postgres" } }
-          contains:
-            lanacl:
-              description:
-              - Language access privileges
-                U(https://www.postgresql.org/docs/current/catalog-pg-language.html).
-              returned: success
-              type: str
-              sample: "{postgres=UC/postgres,=U/postgres}"
-            lanowner:
-              description:
-              - Language owner U(https://www.postgresql.org/docs/current/catalog-pg-language.html).
-              returned: success
-              type: str
-              sample: postgres
-        namespaces:
-          description:
-          - Namespaces (schema) U(https://www.postgresql.org/docs/current/sql-createschema.html).
-          returned: success
-          type: dict
-          sample: { "pg_catalog": { "nspacl": "{postgres=UC/postgres,=U/postgres}", "nspowner": "postgres" } }
-          contains:
-            nspacl:
-              description:
-              - Access privileges U(https://www.postgresql.org/docs/current/catalog-pg-namespace.html).
-              returned: success
-              type: str
-              sample: "{postgres=UC/postgres,=U/postgres}"
-            nspowner:
-              description:
-              - Schema owner U(https://www.postgresql.org/docs/current/catalog-pg-namespace.html).
-              returned: success
-              type: str
-              sample: postgres
-        publications:
-          description:
-          - Information about logical replication publications (available for PostgreSQL 10 and higher)
-            U(https://www.postgresql.org/docs/current/logical-replication-publication.html).
-          - Content depends on PostgreSQL server version.
-          returned: if configured
-          type: dict
-          sample: { "pub1": { "ownername": "postgres", "puballtables": true, "pubinsert": true, "pubupdate": true } }
-          version_added: '0.2.0'
-        subscriptions:
-          description:
-          - Information about replication subscriptions (available for PostgreSQL 10 and higher)
-            U(https://www.postgresql.org/docs/current/logical-replication-subscription.html).
-          - Content depends on PostgreSQL server version.
-          - The return values for the superuser and the normal user may differ
-            U(https://www.postgresql.org/docs/current/catalog-pg-subscription.html).
-          returned: if configured
-          type: dict
-          sample:
-          - { "my_subscription": {"ownername": "postgres", "subenabled": true, "subpublications": ["first_publication"] } }
-          version_added: '0.2.0'
 repl_slots:
   description:
-  - Replication slots (available in 9.4 and later)
-    U(https://www.postgresql.org/docs/current/view-pg-replication-slots.html).
+  - Replication slots (available in 9.4 and later).
   returned: if existent
   type: dict
-  sample: { "slot0": { "active": false, "database": null, "plugin": null, "slot_type": "physical" } }
-  contains:
-    active:
-      description:
-      - True means that a receiver has connected to it, and it is currently reserving archives.
-      returned: success
-      type: bool
-      sample: true
-    database:
-      description: Database name this slot is associated with, or null.
-      returned: success
-      type: str
-      sample: acme
-    plugin:
-      description:
-      - Base name of the shared object containing the output plugin
-        this logical slot is using, or null for physical slots.
-      returned: success
-      type: str
-      sample: pgoutput
-    slot_type:
-      description: The slot type - physical or logical.
-      returned: success
-      type: str
-      sample: logical
 replications:
   description:
-  - Information about the current replications by process PIDs
-    U(https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-STATS-VIEWS-TABLE).
+  - Information about the current replications by process PIDs.
   returned: if pg_stat_replication view existent
   type: dict
-  sample:
-  - { "76580": { "app_name": "standby1", "backend_start": "2019-02-03 00:14:33.908593+03",
-    "client_addr": "10.10.10.2", "client_hostname": "", "state": "streaming", "usename": "postgres" } }
-  contains:
-    usename:
-      description:
-      - Name of the user logged into this WAL sender process ('usename' is a column name in pg_stat_replication view).
-      returned: success
-      type: str
-      sample: replication_user
-    app_name:
-      description: Name of the application that is connected to this WAL sender.
-      returned: if existent
-      type: str
-      sample: acme_srv
-    client_addr:
-      description:
-      - IP address of the client connected to this WAL sender.
-      - If this field is null, it indicates that the client is connected
-        via a Unix socket on the server machine.
-      returned: success
-      type: str
-      sample: 10.0.0.101
-    client_hostname:
-      description:
-      - Host name of the connected client, as reported by a reverse DNS lookup of client_addr.
-      - This field will only be non-null for IP connections, and only when log_hostname is enabled.
-      returned: success
-      type: str
-      sample: dbsrv1
-    backend_start:
-      description: Time when this process was started, i.e., when the client connected to this WAL sender.
-      returned: success
-      type: str
-      sample: "2019-02-03 00:14:33.908593+03"
-    state:
-      description: Current WAL sender state.
-      returned: success
-      type: str
-      sample: streaming
 tablespaces:
   description:
-  - Information about tablespaces U(https://www.postgresql.org/docs/current/catalog-pg-tablespace.html).
+  - Information about tablespaces.
   returned: success
   type: dict
-  sample:
-  - { "test": { "spcacl": "{postgres=C/postgres,andreyk=C/postgres}", "spcoptions": [ "seq_page_cost=1" ],
-    "spcowner": "postgres" } }
-  contains:
-    spcacl:
-      description: Tablespace access privileges.
-      returned: success
-      type: str
-      sample: "{postgres=C/postgres,andreyk=C/postgres}"
-    spcoptions:
-      description: Tablespace-level options.
-      returned: success
-      type: list
-      sample: [ "seq_page_cost=1" ]
-    spcowner:
-      description: Owner of the tablespace.
-      returned: success
-      type: str
-      sample: test_user
 roles:
   description:
-  - Information about roles U(https://www.postgresql.org/docs/current/user-manag.html).
+  - Information about roles.
   returned: success
   type: dict
-  sample:
-  - { "test_role": { "canlogin": true, "member_of": [ "user_ro" ], "superuser": false,
-    "valid_until": "9999-12-31T23:59:59.999999+00:00" } }
-  contains:
-    canlogin:
-      description: Login privilege U(https://www.postgresql.org/docs/current/role-attributes.html).
-      returned: success
-      type: bool
-      sample: true
-    member_of:
-      description:
-      - Role membership U(https://www.postgresql.org/docs/current/role-membership.html).
-      returned: success
-      type: list
-      sample: [ "read_only_users" ]
-    superuser:
-      description: User is a superuser or not.
-      returned: success
-      type: bool
-      sample: false
-    valid_until:
-      description:
-      - Password expiration date U(https://www.postgresql.org/docs/current/sql-alterrole.html).
-      returned: success
-      type: str
-      sample: "9999-12-31T23:59:59.999999+00:00"
 pending_restart_settings:
   description:
-  - List of settings that are pending restart to be set.
+  - List of changed settings that will take effect upon restart .
   returned: success
   type: list
-  sample: [ "shared_buffers" ]
 settings:
   description:
-  - Information about run-time server parameters
-    U(https://www.postgresql.org/docs/current/view-pg-settings.html).
+  - Information about run-time server parameters.
   returned: success
   type: dict
-  sample:
-  - { "work_mem": { "boot_val": "4096", "context": "user", "max_val": "2147483647",
-    "min_val": "64", "setting": "8192", "sourcefile": "/var/lib/pgsql/10/data/postgresql.auto.conf",
-    "unit": "kB", "vartype": "integer", "val_in_bytes": 4194304 } }
-  contains:
-    setting:
-      description: Current value of the parameter.
-      returned: success
-      type: str
-      sample: 49152
-    unit:
-      description: Implicit unit of the parameter.
-      returned: success
-      type: str
-      sample: kB
-    boot_val:
-      description:
-      - Parameter value assumed at server startup if the parameter is not otherwise set.
-      returned: success
-      type: str
-      sample: 4096
-    min_val:
-      description:
-      - Minimum allowed value of the parameter (null for non-numeric values).
-      returned: success
-      type: str
-      sample: 64
-    max_val:
-      description:
-      - Maximum allowed value of the parameter (null for non-numeric values).
-      returned: success
-      type: str
-      sample: 2147483647
-    sourcefile:
-      description:
-      - Configuration file the current value was set in.
-      - Null for values set from sources other than configuration files,
-        or when examined by a user who is neither a superuser or a member of pg_read_all_settings.
-      - Helpful when using include directives in configuration files.
-      returned: success
-      type: str
-      sample: /var/lib/pgsql/10/data/postgresql.auto.conf
-    context:
-      description:
-      - Context required to set the parameter's value.
-      - For more information see U(https://www.postgresql.org/docs/current/view-pg-settings.html).
-      returned: success
-      type: str
-      sample: user
-    vartype:
-      description:
-      - Parameter type (bool, enum, integer, real, or string).
-      returned: success
-      type: str
-      sample: integer
-    val_in_bytes:
-      description:
-      - Current value of the parameter in bytes.
-      returned: if supported
-      type: int
-      sample: 2147483647
-    pretty_val:
-      description:
-      - Value presented in the pretty form.
-      returned: success
-      type: str
-      sample: 2MB
-    pending_restart:
-      description:
-      - True if the value has been changed in the configuration file but needs a restart; or false otherwise.
-      - Returns only if C(settings) is passed.
-      returned: success
-      type: bool
-      sample: false
 '''
 
 import re
 from fnmatch import fnmatch
 
+from ansible.module_utils._text import to_native
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six import iteritems
-from ansible.module_utils._text import to_native
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
     ensure_required_libs,
@@ -530,11 +170,11 @@ from ansible_collections.community.postgresql.plugins.module_utils.postgres impo
     postgres_common_argument_spec,
 )
 
-
 # ===========================================
 # PostgreSQL module specific support methods.
 #
 
+
 class PgDbConn(object):
     """Auxiliary class for working with PostgreSQL connection objects.
 
@@ -590,6 +230,7 @@ class PgClusterInfo(object):
         self.module = module
         self.db_obj = db_conn_obj
         self.cursor = db_conn_obj.connect()
+        self.default_db = self.__get_current_db()
         self.pg_info = {
             "version": {},
             "in_recovery": None,
@@ -977,26 +618,33 @@ class PgClusterInfo(object):
 
     def get_pg_version(self):
         """Get major and minor PostgreSQL server version."""
+        query = "SELECT current_setting('server_version_num')"
+        srv_ver = self.__exec_sql(query)[0]["current_setting"]
         query = "SELECT version()"
         raw = self.__exec_sql(query)[0]["version"]
-        full = raw.split()[1]
-        m = re.match(r"(\d+)\.(\d+)(?:\.(\d+))?", full)
 
-        major = int(m.group(1))
-        minor = int(m.group(2))
-        patch = None
-        if m.group(3) is not None:
-            patch = int(m.group(3))
+        major = int(srv_ver[0:2])
+        minor = int(srv_ver[2:4])
+        patch = int(srv_ver[4:6])
+
+        if minor == 0:
+            # PG 10+
+            full = '.'.join([str(major), str(patch)])
+        else:
+            # PG < 10
+            full = '.'.join([str(major), str(minor), str(patch)])
 
         self.pg_info["version"] = dict(
             major=major,
             minor=minor,
+            patch=patch,
             full=full,
             raw=raw,
         )
 
-        if patch is not None:
-            self.pg_info["version"]["patch"] = patch
+        if minor == 0:
+            self.pg_info["version"]["minor"] = patch
+            self.pg_info["version"]["patch"] = None
 
     def get_recovery_state(self):
         """Get if the service is in recovery mode."""
@@ -1053,6 +701,8 @@ class PgClusterInfo(object):
                 db_dict[datname]['subscriptions'] = subscr_info.get(datname, {})
 
         self.pg_info["databases"] = db_dict
+        # Reconnect to the default DB after gathering info in other DBs
+        self.cursor = self.db_obj.reconnect(self.default_db)
 
     def __get_pretty_val(self, setting):
         """Get setting's value represented by SHOW command."""
@@ -1070,6 +720,13 @@ class PgClusterInfo(object):
             self.cursor.close()
         return False
 
+    def __get_current_db(self):
+        """Get current DB"""
+        # The context is to get the user's default database.
+        # Should be executed right after logging in
+        # https://github.com/ansible-collections/community.postgresql/issues/794
+        return self.__exec_sql('SELECT current_database() AS db')[0]['db']
+
 # ===========================================
 # Module execution.
 #
@@ -1078,7 +735,13 @@ class PgClusterInfo(object):
 def main():
     argument_spec = postgres_common_argument_spec()
     argument_spec.update(
-        db=dict(type='str', aliases=['login_db']),
+        login_db=dict(type='str', aliases=['db'], deprecated_aliases=[
+            {
+                'name': 'db',
+                'version': '4.0.0',
+                'collection_name': 'community.postgresql',
+            }],
+        ),
         filter=dict(type='list', elements='str'),
         session_role=dict(type='str'),
         trust_input=dict(type='bool', default=True),
