@@ -90,9 +90,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            log-all:
+            log_all:
+                aliases: ['log-all']
                 type: str
-                description: Deprecated, please rename it to log_all. Enable/disable logging of all email traffic.
+                description: Enable/disable logging of all email traffic.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -117,8 +118,8 @@ EXAMPLES = '''
         adom: <your own value>
         profile: <your own value>
         emailfilter_profile_gmail:
-          log: <value in [disable, enable]>
-          log_all: <value in [disable, enable]>
+          # log: <value in [disable, enable]>
+          # log_all: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -162,23 +163,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/emailfilter/profile/{profile}/gmail',
         '/pm/config/global/obj/emailfilter/profile/{profile}/gmail'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/emailfilter/profile/{profile}/gmail/{gmail}',
-        '/pm/config/global/obj/emailfilter/profile/{profile}/gmail/{gmail}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = None
     module_arg_spec = {
@@ -191,7 +184,6 @@ def main():
                 'log': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'log-all': {'v_range': [['6.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -200,17 +192,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'emailfilter_profile_gmail'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
