@@ -97,22 +97,25 @@ options:
                 type: int
                 description: ID.
                 required: true
-            remove-ies:
+            remove_ies:
+                aliases: ['remove-ies']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to remove_ies.
+                description: GTP IEs to be removed.
                 choices:
                     - 'apn-restriction'
                     - 'rat-type'
                     - 'rai'
                     - 'uli'
                     - 'imei'
-            sgsn-addr:
+            sgsn_addr:
+                aliases: ['sgsn-addr']
                 type: str
-                description: Deprecated, please rename it to sgsn_addr. SGSN address name.
-            sgsn-addr6:
+                description: SGSN address name.
+            sgsn_addr6:
+                aliases: ['sgsn-addr6']
                 type: str
-                description: Deprecated, please rename it to sgsn_addr6. SGSN IPv6 address name.
+                description: SGSN IPv6 address name.
 '''
 
 EXAMPLES = '''
@@ -200,23 +203,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/ie-remove-policy',
         '/pm/config/global/obj/firewall/gtp/{gtp}/ie-remove-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/ie-remove-policy/{ie-remove-policy}',
-        '/pm/config/global/obj/firewall/gtp/{gtp}/ie-remove-policy/{ie-remove-policy}'
-    ]
-
     url_params = ['adom', 'gtp']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -231,7 +226,6 @@ def main():
                 'sgsn-addr': {'type': 'str'},
                 'sgsn-addr6': {'v_range': [['6.4.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -240,17 +234,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_gtp_ieremovepolicy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
