@@ -124,12 +124,14 @@ options:
                     - 'attacker'
                     - 'both'
                     - 'interface'
-            quarantine-expiry:
+            quarantine_expiry:
+                aliases: ['quarantine-expiry']
                 type: str
-                description: Deprecated, please rename it to quarantine_expiry. Duration of quarantine, from 1 minute to 364 days, 23 hours, and 59 min...
-            quarantine-log:
+                description: Duration of quarantine, from 1 minute to 364 days, 23 hours, and 59 minutes from now.
+            quarantine_log:
+                aliases: ['quarantine-log']
                 type: str
-                description: Deprecated, please rename it to quarantine_log. Enable/disable quarantine logging.
+                description: Enable/disable quarantine logging.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -142,9 +144,10 @@ options:
             threshold:
                 type: int
                 description: Number of detected instances per minute which triggers action
-            threshold(default):
+            threshold_default:
+                aliases: ['threshold(default)']
                 type: int
-                description: Deprecated, please rename it to threshold_default).
+                description: Threshold
             synproxy_tos:
                 type: str
                 description: Determine TCP differentiated services code point value
@@ -389,21 +392,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pkg/{pkg}/firewall/DoS-policy6/{DoS-policy6}/anomaly'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pkg/{pkg}/firewall/DoS-policy6/{DoS-policy6}/anomaly/{anomaly}'
-    ]
-
     url_params = ['adom', 'pkg', 'DoS-policy6']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -444,30 +440,41 @@ def main():
                     'type': 'str'
                 },
                 'synproxy-tos': {
-                    'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
                     'choices': ['0', '10', '12', '14', '18', '20', '22', '26', '28', '30', '34', '36', '38', '40', '46', '255'],
                     'type': 'str'
                 },
                 'synproxy-tcp-window': {
-                    'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
                     'choices': ['4096', '8192', '16384', '32768'],
                     'type': 'str'
                 },
                 'synproxy-tcp-windowscale': {
-                    'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
                     'choices': ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'],
                     'type': 'str'
                 },
-                'synproxy-tcp-timestamp': {'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'synproxy-ttl': {'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']], 'choices': ['32', '64', '128', '255'], 'type': 'str'},
+                'synproxy-tcp-timestamp': {
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'synproxy-ttl': {
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'choices': ['32', '64', '128', '255'],
+                    'type': 'str'
+                },
                 'synproxy-tcp-mss': {
-                    'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
                     'choices': ['0', '256', '512', '1024', '1300', '1360', '1460', '1500'],
                     'type': 'str'
                 },
-                'synproxy-tcp-sack': {'v_range': [['6.2.6', '6.2.12'], ['6.4.2', '7.2.0']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'synproxy-tcp-sack': {
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                }
             }
-
         }
     }
 
@@ -476,17 +483,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_firewall_dospolicy6_anomaly'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
