@@ -143,16 +143,15 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         user_vcenter:
-          name: <string>
-          password: <list or string>
-          rule:
-            -
-              name: <string>
-              rule: <string>
-          server: <string>
-          status: <value in [disable, enable]>
-          upd_interval: <integer>
-          user: <string>
+          name: "your value" # Required variable, string
+          # password: <list or string>
+          # rule:
+          #   - name: <string>
+          #     rule: <string>
+          # server: <string>
+          # status: <value in [disable, enable]>
+          # upd_interval: <integer>
+          # user: <string>
 '''
 
 RETURN = '''
@@ -196,23 +195,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/vcenter',
         '/pm/config/global/obj/user/vcenter'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/vcenter/{vcenter}',
-        '/pm/config/global/obj/user/vcenter/{vcenter}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -234,7 +225,6 @@ def main():
                 'upd_interval': {'v_range': [['6.4.0', '']], 'type': 'int'},
                 'user': {'v_range': [['6.4.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -243,14 +233,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_vcenter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
