@@ -143,12 +143,12 @@ EXAMPLES = '''
         host_check_software: <your own value>
         state: present # <value in [present, absent]>
         vpnsslweb_hostchecksoftware_checkitemlist:
-          action: <value in [deny, require]>
-          id: <integer>
-          md5s: <list or string>
-          target: <string>
-          type: <value in [file, registry, process]>
-          version: <string>
+          id: 0 # Required variable, integer
+          # action: <value in [deny, require]>
+          # md5s: <list or string>
+          # target: <string>
+          # type: <value in [file, registry, process]>
+          # version: <string>
 '''
 
 RETURN = '''
@@ -192,23 +192,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/vpn/ssl/web/host-check-software/{host-check-software}/check-item-list',
         '/pm/config/global/obj/vpn/ssl/web/host-check-software/{host-check-software}/check-item-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/vpn/ssl/web/host-check-software/{host-check-software}/check-item-list/{check-item-list}',
-        '/pm/config/global/obj/vpn/ssl/web/host-check-software/{host-check-software}/check-item-list/{check-item-list}'
-    ]
-
     url_params = ['adom', 'host-check-software']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -226,7 +218,6 @@ def main():
                 'type': {'choices': ['file', 'registry', 'process'], 'type': 'str'},
                 'version': {'type': 'str'}
             }
-
         }
     }
 
@@ -235,14 +226,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpnsslweb_hostchecksoftware_checkitemlist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
