@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 '''
@@ -139,12 +139,21 @@ options:
 
   subnet_name:
     description:
-      - Subnet where the interface address is allocated from.
-      - If the option is not used, the IP address will need to be provided by the administrator during configuration.
-      - Not supported in REST.
+      - Subnet where the IP interface address is allocated from.
+      - If the option is not used, the IP address and netmask need to be provided.
+      - With REST, ONTAP 9.11.1 or later is required.
+      - With REST, ipspace must be set.
     version_added: 2.8.0
     type: str
 
+  fail_if_subnet_conflicts:
+    description:
+      - Creating or updating an IP Interface fails if the specified IP address falls within the address range of a named subnet.
+      - Set this value to false to use the specified IP address and to assign the subnet owning that address to the interface.
+      - This option is only supported with REST and requires ONTAP 9.11.1 or later.
+    version_added: 22.2.0
+    type: bool
+
   admin_status:
     choices: ['up', 'down']
     description:
@@ -237,6 +246,7 @@ options:
     description:
       - IPspace name is required with REST for cluster-scoped interfaces.  It is optional with SVM scope.
       - ignored with ZAPI.
+      - ignored for FC interface.
     type: str
     version_added: 21.13.0
 
@@ -260,139 +270,138 @@ options:
     elements: str
     default: ['force_subnet_association']
     version_added: 21.13.0
+
+  probe_port:
+    description:
+      - Probe port for Cloud load balancer - only valid in the Azure environment.
+      - Not supported with ZAPI or with FC interfaces.
+      - Requires ONTAP 9.10.1 or later.
+    type: int
+    version_added: 22.1.0
 notes:
   - REST support requires ONTAP 9.7 or later.
   - Support check_mode.
 '''
 
 EXAMPLES = '''
-    - name: Create interface - ZAPI
-      netapp.ontap.na_ontap_interface:
-        state: present
-        interface_name: data2
-        home_port: e0d
-        home_node: laurentn-vsim1
-        role: data
-        protocols:
-          - nfs
-          - cifs
-        admin_status: up
-        failover_policy: local-only
-        firewall_policy: mgmt
-        is_auto_revert: true
-        address: 10.10.10.10
-        netmask: 255.255.255.0
-        force_subnet_association: false
-        dns_domain_name: test.com
-        listen_for_dns_query: true
-        is_dns_update_enabled: true
-        vserver: svm1
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create interface - ZAPI
+  netapp.ontap.na_ontap_interface:
+    state: present
+    interface_name: data2
+    home_port: e0d
+    home_node: laurentn-vsim1
+    role: data
+    protocols:
+      - nfs
+      - cifs
+    admin_status: up
+    failover_policy: local-only
+    firewall_policy: mgmt
+    is_auto_revert: true
+    address: 10.10.10.10
+    netmask: 255.255.255.0
+    force_subnet_association: false
+    dns_domain_name: test.com
+    listen_for_dns_query: true
+    is_dns_update_enabled: true
+    vserver: svm1
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Create data interface - REST - NAS
-      netapp.ontap.na_ontap_interface:
-        state: present
-        interface_name: data2
-        home_port: e0d
-        home_node: laurentn-vsim1
-        admin_status: up
-        failover_scope: home_node_only
-        service_policy: default-data-files
-        is_auto_revert: true
-        interface_type: ip
-        address: 10.10.10.10
-        netmask: 255.255.255.0
-        vserver: svm1
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create data interface - REST - NAS
+  netapp.ontap.na_ontap_interface:
+    state: present
+    interface_name: data2
+    home_port: e0d
+    home_node: laurentn-vsim1
+    admin_status: up
+    failover_scope: home_node_only
+    service_policy: default-data-files
+    is_auto_revert: true
+    interface_type: ip
+    address: 10.10.10.10
+    netmask: 255.255.255.0
+    vserver: svm1
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Create cluster interface - ZAPI
-      netapp.ontap.na_ontap_interface:
-        state: present
-        interface_name: cluster_lif
-        home_port: e0a
-        home_node: cluster1-01
-        role: cluster
-        admin_status: up
-        is_auto_revert: true
-        is_ipv4_link_local: true
-        vserver: Cluster
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create cluster interface - ZAPI
+  netapp.ontap.na_ontap_interface:
+    state: present
+    interface_name: cluster_lif
+    home_port: e0a
+    home_node: cluster1-01
+    role: cluster
+    admin_status: up
+    is_auto_revert: true
+    is_ipv4_link_local: true
+    vserver: Cluster
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Create cluster interface - REST
-      netapp.ontap.na_ontap_interface:
-        state: present
-        interface_name: cluster_lif
-        home_port: e0a
-        home_node: cluster1-01
-        service_policy: default-cluster
-        admin_status: up
-        is_auto_revert: true
-        vserver: Cluster
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create cluster interface - REST
+  netapp.ontap.na_ontap_interface:
+    state: present
+    interface_name: cluster_lif
+    home_port: e0a
+    home_node: cluster1-01
+    service_policy: default-cluster
+    admin_status: up
+    is_auto_revert: true
+    vserver: Cluster
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Rename interface
-      netapp.ontap.na_ontap_interface:
-        state: present
-        from_name: ansibleSVM_lif
-        interface_name: ansibleSVM_lif01
-        vserver: ansibleSVM
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Rename interface
+  netapp.ontap.na_ontap_interface:
+    state: present
+    from_name: ansibleSVM_lif
+    interface_name: ansibleSVM_lif01
+    vserver: ansibleSVM
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Migrate an interface
-      netapp.ontap.na_ontap_interface:
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        vserver: ansible
-        https: true
-        validate_certs: false
-        state: present
-        interface_name: carchi_interface3
-        home_port: e0d
-        home_node: ansdev-stor-1
-        current_node: ansdev-stor-2
-        role: data
-        failover_policy: local-only
-        firewall_policy: mgmt
-        is_auto_revert: true
-        address: 10.10.10.12
-        netmask: 255.255.255.0
-        force_subnet_association: false
-        admin_status: up
-
-    - name: Delete interface
-      netapp.ontap.na_ontap_interface:
-        state: absent
-        interface_name: data2
-        vserver: svm1
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Migrate an interface
+  netapp.ontap.na_ontap_interface:
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    vserver: ansible
+    https: true
+    validate_certs: false
+    state: present
+    interface_name: carchi_interface3
+    home_port: e0d
+    home_node: ansdev-stor-1
+    current_node: ansdev-stor-2
+    role: data
+    failover_policy: local-only
+    firewall_policy: mgmt
+    is_auto_revert: true
+    address: 10.10.10.12
+    netmask: 255.255.255.0
+    force_subnet_association: false
+    admin_status: up
 
+- name: Delete interface
+  netapp.ontap.na_ontap_interface:
+    state: absent
+    interface_name: data2
+    vserver: svm1
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 '''
 
 RETURN = """
 
 """
 
-try:
-    import ipaddress
-    HAS_IPADDRESS_LIB = True
-    IMPORT_ERROR = None
-except ImportError as exc:
-    HAS_IPADDRESS_LIB = False
-    IMPORT_ERROR = str(exc)
-
 import time
 import traceback
 from ansible.module_utils.basic import AnsibleModule
@@ -400,28 +409,14 @@ from ansible.module_utils._text import to_native
 from ansible_collections.netapp.ontap.plugins.module_utils.netapp_module import NetAppModule
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.ontap.plugins.module_utils.netapp import OntapRestAPI
-from ansible_collections.netapp.ontap.plugins.module_utils import rest_generic
+from ansible_collections.netapp.ontap.plugins.module_utils import rest_generic, netapp_ipaddress
 
 FAILOVER_POLICIES = ['disabled', 'system-defined', 'local-only', 'sfo-partner-only', 'broadcast-domain-wide']
 FAILOVER_SCOPES = ['home_port_only', 'default', 'home_node_only', 'sfo_partners_only', 'broadcast_domain_only']
-REST_UNSUPPORTED_OPTIONS = ['is_ipv4_link_local', 'subnet_name', ]
+REST_UNSUPPORTED_OPTIONS = ['is_ipv4_link_local']
 REST_IGNORABLE_OPTIONS = ['failover_group', 'force_subnet_association', 'listen_for_dns_query']
 
 
-def get_network(ip, mask):
-    # python 2.7 requires the address to be in unicode format (which is the default for 3.x)
-    net = u'%s/%s' % (ip, mask)
-    return ipaddress.ip_network(net, strict=False)
-
-
-def netmask_length_to_netmask(ip, length):
-    return str(get_network(ip, length).netmask)
-
-
-def netmask_to_netmask_length(ip, netmask):
-    return str(get_network(ip, netmask).prefixlen)
-
-
 class NetAppOntapInterface:
     ''' object to describe  interface info '''
 
@@ -463,7 +458,9 @@ class NetAppOntapInterface:
             is_dns_update_enabled=dict(required=False, type='bool'),
             service_policy=dict(required=False, type='str', default=None),
             from_name=dict(required=False, type='str'),
-            ignore_zapi_options=dict(required=False, type='list', elements='str', default=['force_subnet_association'], choices=REST_IGNORABLE_OPTIONS)
+            ignore_zapi_options=dict(required=False, type='list', elements='str', default=['force_subnet_association'], choices=REST_IGNORABLE_OPTIONS),
+            probe_port=dict(required=False, type='int'),
+            fail_if_subnet_conflicts=dict(required=False, type='bool'),
         ))
 
         self.module = AnsibleModule(
@@ -483,29 +480,37 @@ class NetAppOntapInterface:
         self.rest_api = OntapRestAPI(self.module)
         unsupported_rest_properties = [key for key in REST_IGNORABLE_OPTIONS if key not in self.parameters['ignore_zapi_options']]
         unsupported_rest_properties.extend(REST_UNSUPPORTED_OPTIONS)
-        partially_supported_rest_properties = [['dns_domain_name', (9, 9, 0)], ['is_dns_update_enabled', (9, 9, 1)]]
+        if self.na_helper.safe_get(self.parameters, ['address']):
+            self.parameters['address'] = netapp_ipaddress.validate_and_compress_ip_address(self.parameters['address'], self.module)
+        partially_supported_rest_properties = [['dns_domain_name', (9, 9, 0)], ['is_dns_update_enabled', (9, 9, 1)], ['probe_port', (9, 10, 1)],
+                                               ['subnet_name', (9, 11, 1)], ['fail_if_subnet_conflicts', (9, 11, 1)]]
         self.use_rest = self.rest_api.is_rest_supported_properties(self.parameters, unsupported_rest_properties, partially_supported_rest_properties)
         if self.use_rest and not self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 7, 0):
             msg = 'REST requires ONTAP 9.7 or later for interface APIs.'
             self.use_rest = self.na_helper.fall_back_to_zapi(self.module, msg, self.parameters)
 
-        if self.use_rest and not HAS_IPADDRESS_LIB:
-            msg = "the python ipaddress package is required for this module: %s" % IMPORT_ERROR
-            if self.parameters['use_rest'].lower() == 'always':
-                self.module.fail_json(msg='Error: %s' % msg)
-            self.module.warn('Falling back to ZAPI: %s' % msg)
-            self.use_rest = False
         if self.use_rest:
             self.cluster_nodes = None       # cached value to limit number of API calls.
             self.home_node = None           # cached value to limit number of API calls.
             self.map_failover_policy()
             self.validate_rest_input_parameters()
+            # REST supports both netmask and cidr for ipv4 but cidr only for ipv6.
+            if self.parameters.get('netmask'):
+                self.parameters['netmask'] = str(netapp_ipaddress.netmask_to_netmask_length(self.parameters.get('address'),
+                                                                                            self.parameters['netmask'], self.module))
         elif netapp_utils.has_netapp_lib() is False:
             self.module.fail_json(msg=netapp_utils.netapp_lib_is_required())
         else:
+            for option in ('probe_port', 'fail_if_subnet_conflicts'):
+                if self.parameters.get(option) is not None:
+                    self.module.fail_json(msg='Error option %s requires REST.' % option)
             if 'vserver' not in self.parameters:
                 self.module.fail_json(msg='missing required argument with ZAPI: vserver')
             self.server = netapp_utils.setup_na_ontap_zapi(module=self.module)
+            # ZAPI supports only netmask.
+            if self.parameters.get('netmask'):
+                self.parameters['netmask'] = netapp_ipaddress.netmask_length_to_netmask(self.parameters.get('address'),
+                                                                                        self.parameters['netmask'], self.module)
 
     def map_failover_policy(self):
         if self.use_rest and 'failover_policy' in self.parameters:
@@ -538,9 +543,7 @@ class NetAppOntapInterface:
     def derive_interface_type(self):
         protocols = self.parameters.get('protocols')
         if protocols in (None, ["none"]):
-            if self.parameters.get('role') in ('cluster', 'intercluster'):
-                self.set_interface_type('ip')
-            if 'address' in self.parameters or 'netmask' in self.parameters:
+            if self.parameters.get('role') in ('cluster', 'intercluster') or any(x in self.parameters for x in ('address', 'netmask', 'subnet_name')):
                 self.set_interface_type('ip')
             return
         protocol_types = set()
@@ -590,7 +593,10 @@ class NetAppOntapInterface:
 
     def get_interface_records_rest(self, if_type, query, fields):
         if 'ipspace' in self.parameters:
-            query['ipspace.name'] = self.parameters['ipspace']
+            if if_type == 'ip':
+                query['ipspace.name'] = self.parameters['ipspace']
+            else:
+                self.module.warn("ipspace is ignored for FC interfaces.")
         records, error = rest_generic.get_0_or_more_records(self.rest_api, self.get_net_int_api(if_type), query, fields)
         if error and 'are available in precluster.' in error:
             # in precluster mode, network APIs are not available!
@@ -646,7 +652,7 @@ class NetAppOntapInterface:
                                       % (name, [record['name'] for record in (record, home_record)]))
         if home_record:
             record = home_record
-        if record and self.parameters.get('interface_name') != record['name']:
+        if record and name == self.parameters['interface_name'] and name != record['name']:
             # fix name, otherwise we'll attempt a rename :(
             self.parameters['interface_name'] = record['name']
             self.module.warn('adjusting name from %s to %s' % (name, record['name']))
@@ -681,8 +687,12 @@ class NetAppOntapInterface:
         fields_ip = fields + ',ip,service_policy'
         if self.parameters.get('dns_domain_name'):
             fields_ip += ',dns_zone'
-        if 'is_dns_update_enabled' in self.parameters:
+        if self.parameters.get('probe_port') is not None:
+            fields_ip += ',probe_port'
+        if self.parameters.get('is_dns_update_enabled') is not None:
             fields_ip += ',ddns_enabled'
+        if self.parameters.get('subnet_name') is not None:
+            fields_ip += ',subnet'
         records, error, records2, error2 = None, None, None, None
         if if_type in [None, 'ip']:
             records, error = self.get_interface_records_rest('ip', query_ip, fields_ip)
@@ -738,9 +748,9 @@ class NetAppOntapInterface:
         # if interface_attributes.get_child_by_name('failover-group'):
         #     return_value['failover_group'] = interface_attributes['failover-group']
         if self.na_helper.safe_get(record, ['ip', 'address']):
-            return_value['address'] = record['ip']['address']
-            if self.na_helper.safe_get(record, ['ip', 'netmask']):
-                return_value['netmask'] = netmask_length_to_netmask(record['ip']['address'], record['ip']['netmask'])
+            return_value['address'] = netapp_ipaddress.validate_and_compress_ip_address(record['ip']['address'], self.module)
+            if self.na_helper.safe_get(record, ['ip', 'netmask']) is not None:
+                return_value['netmask'] = record['ip']['netmask']
         if self.na_helper.safe_get(record, ['service_policy', 'name']):
             return_value['service_policy'] = record['service_policy']['name']
         if self.na_helper.safe_get(record, ['location', 'node', 'name']):
@@ -749,8 +759,12 @@ class NetAppOntapInterface:
             return_value['current_port'] = record['location']['port']['name']
         if self.na_helper.safe_get(record, ['dns_zone']):
             return_value['dns_domain_name'] = record['dns_zone']
+        if self.na_helper.safe_get(record, ['probe_port']) is not None:
+            return_value['probe_port'] = record['probe_port']
         if 'ddns_enabled' in record:
             return_value['is_dns_update_enabled'] = record['ddns_enabled']
+        if self.na_helper.safe_get(record, ['subnet', 'name']):
+            return_value['subnet_name'] = record['subnet']['name']
         return return_value
 
     def get_node_port(self, uuid):
@@ -806,7 +820,7 @@ class NetAppOntapInterface:
             if interface_attributes.get_child_by_name('failover-group'):
                 return_value['failover_group'] = interface_attributes['failover-group']
             if interface_attributes.get_child_by_name('address'):
-                return_value['address'] = interface_attributes['address']
+                return_value['address'] = netapp_ipaddress.validate_and_compress_ip_address(interface_attributes['address'], self.module)
             if interface_attributes.get_child_by_name('netmask'):
                 return_value['netmask'] = interface_attributes['netmask']
             if interface_attributes.get_child_by_name('firewall-policy'):
@@ -903,7 +917,6 @@ class NetAppOntapInterface:
 
     def set_options_rest(self, parameters):
         """ set attributes for create or modify """
-
         def add_ip(options, key, value):
             if 'ip' not in options:
                 options['ip'] = {}
@@ -943,10 +956,8 @@ class NetAppOntapInterface:
             'interface_name': 'name',
             'vserver': 'svm.name',
             # LOCATION
-            'current_node': 'node',
             'current_port': 'port',
-            'home_node': 'home_node',
-            'home_port': 'home_port',
+            'home_port': 'home_port'
         }
         if self.parameters['interface_type'] == 'ip':
             mapping_params_to_rest.update({
@@ -954,6 +965,9 @@ class NetAppOntapInterface:
                 'service_policy': 'service_policy',
                 'dns_domain_name': 'dns_zone',
                 'is_dns_update_enabled': 'ddns_enabled',
+                'probe_port': 'probe_port',
+                'subnet_name': 'subnet.name',
+                'fail_if_subnet_conflicts': 'fail_if_subnet_conflicts',
                 # IP
                 'address': 'address',
                 'netmask': 'netmask',
@@ -961,6 +975,9 @@ class NetAppOntapInterface:
                 'broadcast_domain': 'broadcast_domain',
                 'failover_scope': 'failover',
                 'is_auto_revert': 'auto_revert',
+                # home_node/current_node supported only in ip interfaces.
+                'home_node': 'home_node',
+                'current_node': 'node'
             })
         if self.parameters['interface_type'] == 'fc':
             mapping_params_to_rest['data_protocol'] = 'data_protocol'
@@ -990,7 +1007,7 @@ class NetAppOntapInterface:
                 else:
                     options[rkey] = parameters[pkey]
 
-        keys_in_error = ('role', 'subnet_name', 'failover_group', 'firewall_policy', 'force_subnet_association',
+        keys_in_error = ('role', 'failover_group', 'firewall_policy', 'force_subnet_association',
                          'listen_for_dns_query', 'is_ipv4_link_local')
         for pkey in keys_in_error:
             if pkey in parameters:
@@ -1071,7 +1088,8 @@ class NetAppOntapInterface:
             if 'vserver' not in self.parameters and 'ipspace' not in self.parameters:
                 errors.append('ipspace name must be provided if scope is cluster, or vserver for svm scope.')
             if self.parameters['interface_type'] == 'fc':
-                unsupported_fc_options = ['broadcast_domain', 'dns_domain_name', 'is_dns_update_enabled']
+                unsupported_fc_options = ['broadcast_domain', 'dns_domain_name', 'is_dns_update_enabled', 'probe_port', 'subnet_name',
+                                          'fail_if_subnet_conflicts']
                 used_unsupported_fc_options = [option for option in unsupported_fc_options if option in self.parameters]
                 if used_unsupported_fc_options:
                     plural = 's' if len(used_unsupported_fc_options) > 1 else ''
@@ -1126,6 +1144,8 @@ class NetAppOntapInterface:
                     errors.append("'service_policy' is not supported for FC interfaces.")
                 if 'role' in self.parameters and self.parameters.get('role') != 'data':
                     errors.append("'role' is deprecated, and 'data' is the only value supported for FC interfaces: found %s." % self.parameters.get('role'))
+                if 'probe_port' in self.parameters:
+                    errors.append("'probe_port' is not supported for FC interfaces.")
         if errors:
             self.module.fail_json(msg='Error: %s' % '  '.join(errors))
 
@@ -1133,7 +1153,8 @@ class NetAppOntapInterface:
         """ Only the following keys can be modified:
             enabled, ip, location, name, service_policy
         """
-        bad_keys = [key for key in body if key not in ['enabled', 'ip', 'location', 'name', 'service_policy', 'dns_zone', 'ddns_enabled']]
+        bad_keys = [key for key in body if key not in ['enabled', 'ip', 'location', 'name', 'service_policy', 'dns_zone', 'ddns_enabled', 'subnet.name',
+                                                       'fail_if_subnet_conflicts']]
         if bad_keys:
             plural = 's' if len(bad_keys) > 1 else ''
             self.module.fail_json(msg='The following option%s cannot be modified: %s' % (plural, ', '.join(bad_keys)))
@@ -1143,7 +1164,11 @@ class NetAppOntapInterface:
         # running validation twice, as interface_type dictates the second set of requirements
         self.validate_required_parameters(required_keys)
         self.validate_rest_input_parameters(action='modify' if modify else 'create')
-        if not modify:
+        if modify:
+            # force the value of fail_if_subnet_conflicts as it is writeOnly
+            if self.parameters.get('fail_if_subnet_conflicts') is not None:
+                modify['fail_if_subnet_conflicts'] = self.parameters['fail_if_subnet_conflicts']
+        else:
             required_keys = set()
             required_keys.add('interface_name')
             if self.parameters['interface_type'] == 'fc':
@@ -1151,10 +1176,14 @@ class NetAppOntapInterface:
                 required_keys.add('data_protocol')
                 if 'home_port' not in self.parameters:
                     # home_port is not supported with 9.7
-                    required_keys.add('current_port')
+                    if self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 8, 0):
+                        required_keys.add('home_port')
+                    else:
+                        required_keys.add('current_port')
             if self.parameters['interface_type'] == 'ip':
-                required_keys.add('address')
-                required_keys.add('netmask')
+                if 'subnet_name' not in self.parameters:
+                    required_keys.add('address')
+                    required_keys.add('netmask')
                 required_keys.add('broadcast_domain_home_port_or_home_node')
             self.validate_required_parameters(required_keys)
         body, migrate_body, errors = self.set_options_rest(modify)
@@ -1370,18 +1399,27 @@ class NetAppOntapInterface:
             if cd_action == 'create':
                 body, migrate_body = self.build_rest_body()
             elif modify:
+                # fc interface supports only home_port and port in POST/PATCH.
+                # add home_port and current_port in modify for home_node and current_node respectively to form home_port/port.
+                if modify.get('home_node') and not modify.get('home_port') and self.parameters['interface_type'] == 'fc':
+                    modify['home_port'] = current['home_port']
+                # above will modify home_node of fc interface, after modify if requires to update current_node, it will error out for fc interface.
+                # migrate not supported for fc interface.
+                if modify.get('current_node') and not modify.get('current_port') and self.parameters['interface_type'] == 'fc':
+                    modify['current_port'] = current['current_port']
                 body, migrate_body = self.build_rest_body(modify)
             if (modify or cd_action == 'delete') and uuid is None:
                 self.module.fail_json(msg='Error, expecting uuid in existing record')
+            desired_home_port = self.na_helper.safe_get(body, ['location', 'home_port'])
+            desired_current_port = self.na_helper.safe_get(migrate_body, ['location', 'port'])
+            # if try to modify both home_port and current_port in FC interface and if its equal, make migrate_body None
+            if self.parameters.get('interface_type') == 'fc' and desired_home_port and desired_current_port and desired_home_port == desired_current_port:
+                migrate_body = None
         return uuid, body, migrate_body
 
     def apply(self):
         ''' calling all interface features '''
-        if not self.use_rest:
-            netapp_utils.ems_log_event_cserver("na_ontap_interface", self.server, self.module)
         cd_action, modify, rename, current = self.get_action()
-        uuid = current.get('uuid') if current else None
-
         # build the payloads even in check_mode, to perform validations
         uuid, body, migrate_body = self.build_rest_payloads(cd_action, modify, current)
         if self.na_helper.changed and not self.module.check_mode:
@@ -1400,12 +1438,13 @@ class NetAppOntapInterface:
             elif modify:
                 self.modify_interface(modify, uuid, body)
             if migrate_body:
+                # for 9.7 or earlier, allow modify current node/port for fc interface.
+                if self.parameters.get('interface_type') == 'fc' and self.use_rest and self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 8, 0):
+                    self.module.fail_json(msg="Error: cannot migrate FC interface")
                 self.migrate_interface_rest(uuid, migrate_body)
 
-        results = {'changed': self.na_helper.changed}
-        if netapp_utils.has_feature(self.module, 'show_modified'):
-            results['modify'] = str(modify)
-        self.module.exit_json(**results)
+        result = netapp_utils.generate_result(self.na_helper.changed, cd_action, modify)
+        self.module.exit_json(**result)
 
 
 def main():
